summaryrefslogtreecommitdiffstats
path: root/net/ftp/ftp_transaction.h
diff options
context:
space:
mode:
authorwillchan@chromium.org <willchan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-10-01 20:38:10 +0000
committerwillchan@chromium.org <willchan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-10-01 20:38:10 +0000
commitf1f3f0f8af3740ec2afaebcaed410950a9cc0ac8 (patch)
tree6ccdd87ccfc89adbcb372c517559fa61fbc6c6b2 /net/ftp/ftp_transaction.h
parentd1666539b57bf8552e203d355fd09909d36f9732 (diff)
downloadchromium_src-f1f3f0f8af3740ec2afaebcaed410950a9cc0ac8.zip
chromium_src-f1f3f0f8af3740ec2afaebcaed410950a9cc0ac8.tar.gz
chromium_src-f1f3f0f8af3740ec2afaebcaed410950a9cc0ac8.tar.bz2
Begin CompletionCallback switchover.
Rename CompletionCallback to OldCompletionCallback in preparation for introducing a new CompletionCallback based on base::Callback. Also renames other CompletionCallback types like CancelableCompletionCallback and TestCompletionCallback and CompletionCallbackImpl. All using sed with s/CompletionCallback/OldCompletionCallback/g. BUG=98719 TEST=none Review URL: http://codereview.chromium.org/8070013 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@103650 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/ftp/ftp_transaction.h')
-rw-r--r--net/ftp/ftp_transaction.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/net/ftp/ftp_transaction.h b/net/ftp/ftp_transaction.h
index 2d1c5d8..300468b 100644
--- a/net/ftp/ftp_transaction.h
+++ b/net/ftp/ftp_transaction.h
@@ -29,7 +29,7 @@ class NET_EXPORT_PRIVATE FtpTransaction {
// Returns OK if the transaction could be started synchronously, which means
// that the request was served from the cache (only supported for directory
// listings). ERR_IO_PENDING is returned to indicate that the
// CompletionCallback will be notified once response info is available or if
// an IO error occurs. Any other return value indicates that the transaction
// could not be started.
//
@@ -40,22 +40,22 @@ class NET_EXPORT_PRIVATE FtpTransaction {
//
// Profiling information for the request is saved to |net_log| if non-NULL.
virtual int Start(const FtpRequestInfo* request_info,
- CompletionCallback* callback,
+ OldCompletionCallback* callback,
const BoundNetLog& net_log) = 0;
// Restarts the FTP transaction with authentication credentials.
virtual int RestartWithAuth(const string16& username,
const string16& password,
- CompletionCallback* callback) = 0;
+ OldCompletionCallback* callback) = 0;
// Once response info is available for the transaction, response data may be
// read by calling this method.
//
// Response data is copied into the given buffer and the number of bytes
// copied is returned. ERR_IO_PENDING is returned if response data is not
// yet available. The CompletionCallback is notified when the data copy
// completes, and it is passed the number of bytes that were successfully
// copied. Or, if a read error occurs, the CompletionCallback is notified of
// the error. Any other negative return value indicates that the transaction
// could not be read.
//
@@ -63,7 +63,7 @@ class NET_EXPORT_PRIVATE FtpTransaction {
//
virtual int Read(IOBuffer* buf,
int buf_len,
- CompletionCallback* callback) = 0;
+ OldCompletionCallback* callback) = 0;
// Returns the response info for this transaction or NULL if the response
// info is not available.
@@ -29,7 +29,7 @@ class NET_EXPORT_PRIVATE FtpTransaction {
// that the request was served from the cache (only supported for directory
// listings). ERR_IO_PENDING is returned to indicate that the
- // CompletionCallback will be notified once response info is available or if
+ // OldCompletionCallback will be notified once response info is available or if
// an IO error occurs. Any other return value indicates that the transaction
// could not be started.
@@ -40,22 +40,22 @@ class NET_EXPORT_PRIVATE FtpTransaction {
// Response data is copied into the given buffer and the number of bytes
// copied is returned. ERR_IO_PENDING is returned if response data is not
- // yet available. The CompletionCallback is notified when the data copy
+ // yet available. The OldCompletionCallback is notified when the data copy
// completes, and it is passed the number of bytes that were successfully
@@ -40,22 +40,22 @@ class NET_EXPORT_PRIVATE FtpTransaction {
// completes, and it is passed the number of bytes that were successfully
- // copied. Or, if a read error occurs, the CompletionCallback is notified of
+ // copied. Or, if a read error occurs, the OldCompletionCallback is notified of
// the error. Any other negative return value indicates that the transaction
// could not be read.